@@ -3,7 +3,7 @@
  * mpg4@duluoz.net
  *
  * Johan Ekenberg
- * johan@ekenberg.nu
+ * johan@ekenberg.se
  *
  * output.h
  * talk to the nice people
@@ -17,11 +17,11 @@
 
 extern int output_level;
 
-inline void   output_version (void);
-inline void   output_help (void);
+void   output_version (void);
+void   output_help (void);
 
-inline void   output_debug (const char *format, ...);
-inline void   output_info (const char *format, ...);
-inline void   output_error (const char *format, ...);
+void   output_debug (const char *format, ...);
+void   output_info (const char *format, ...);
+void   output_error (const char *format, ...);
 
 #endif /* INCLUDE_QUOTATOOL_OUTPUT */
